@@ -1,5 +1,6 @@
 import logging, simplejson
 from monscale.mappings.cloudforms import start_vm
+from monscale.mappings.aws import publish_msg_to_sns_topic
 
 
 def _load_data(data):
@@ -32,6 +33,9 @@ def launch_cloudforms_vmachine(data):
 def destroy_cloudforms_vmachine(data):
     pass
 
+
+
 mappings = [
-    launch_cloudforms_vmachine,    
+    launch_cloudforms_vmachine,   
+    publish_msg_to_sns_topic, 
     ]
\ No newline at end of file
